@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.091-9-gf92b8f1
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.092-11-ge557d6e
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.092';
+our $VERSION = '0.093';
 
 use Moose;
 with
@@ -181,7 +181,7 @@ sub configure
         [ 'Test::PodSpelling'   => { ':version' => '2.006001' } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
         'Test::Pod::No404s',
-        [ 'Test::Kwalitee'      => { ':version' => '2.06' } ],
+        [ 'Test::Kwalitee'      => { ':version' => '2.06', filename => 'xt/author/kwalitee.t' } ],
         'MojibakeTests',
         [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1,
             exists $removed{PodCoverageTests} ? () : ( include => [ 'Pod::Coverage' ] ),
@@ -213,7 +213,7 @@ sub configure
         [ 'AuthorityFromModule' => { ':version' => '0.002' } ],
         [ 'Authority'           => { authority => 'cpan:ETHER', do_munging => 0 } ],
         [ 'MetaNoIndex'         => { directory => [ qw(t xt), grep { -d } qw(inc local perl5 fatlib examples share corpus demo) ] } ],
-        [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 1 } ],
+        [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 0 } ],
         'MetaConfig',
         [ 'Keywords'            => { ':version' => '0.004' } ],
         [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
@@ -242,9 +242,9 @@ sub configure
         'CheckSelfDependency',
 
         ( $has_bash ?
-            [ 'Run::AfterBuild' => '.ackrc' => { run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
+            [ 'Run::AfterBuild' => '.ackrc' => { ':version' => '0.038', quiet => 1, run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
             : ()),
-        [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.028', eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
+        [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.038', quiet => 1, eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
 
 
         # Before Release
@@ -265,7 +265,7 @@ sub configure
         # After Release
         [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
         ( -e 'README.md' ?
-            [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.024', eval => q!unlink 'README.md'! } ]
+            [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.038', quiet => 1, eval => q!unlink 'README.md'! } ]
             : ()),
         [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } uniq 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
@@ -303,7 +303,7 @@ sub configure
     }
 
     push @plugins, (
-        [ 'Run::AfterRelease'   => 'release complete' => { ':version' => '0.024', eval => [ qq{print "release complete!\\xa"} ] } ],
+        [ 'Run::AfterRelease'   => 'release complete' => { ':version' => '0.038', quiet => 1, eval => [ qq{print "release complete!\\xa"} ] } ],
         # listed late, to allow all other plugins which do BeforeRelease checks to run first.
         'ConfirmRelease',
     );
@@ -371,7 +371,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.092
+version 0.093
 
 =head1 SYNOPSIS
 
@@ -466,19 +466,23 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Test::ChangesHasContent]
     [Test::MinimumVersion]
     :version = 2.000003
-    max_target_perl = 5.008001
+    max_target_perl = 5.006
     [PodSyntaxTests]
     [PodCoverageTests]
     [Test::PodSpelling]
     ;[Test::Pod::LinkCheck]     many outstanding bugs
     [Test::Pod::No404s]
     [Test::Kwalitee]
+    :version = 2.06
+    filename => xt/author/kwalitee.t
     [MojibakeTests]
     [Test::ReportPrereqs]
     :version = 0.019
     verify_prereqs = 1
     include = Pod::Coverage
     [Test::Portability]
+    [Test::CleanNamespaces]
+    :version = 0.006
 
 
     ;;; Munge Files
@@ -530,7 +534,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     finder = :InstallModules
     meta_noindex = 1
     inherit_version = 0
-    inherit_missing = 1
+    inherit_missing = 0
 
     [MetaConfig]
     [Keywords]
@@ -573,9 +577,12 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [CheckSelfDependency]
 
     [Run::AfterBuild / .ackrc]
+    :version = 0.38
+    quiet = 1
     run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi; if [[ %d =~ ^%n-[.[:xdigit:]]+$ ]]; then rm -f .latest; ln -s %d .latest; fi"
     [Run::AfterBuild / .latest]
-    :version = 0.028
+    :version = 0.038
+    quiet = 1
     eval = if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }
 
 
@@ -617,7 +624,8 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     filename = Changes
 
     [Run::AfterRelease / remove old READMEs]
-    :version = 0.024
+    :version = 0.038
+    quiet = 1
     eval = unlink 'README.md'
 
     [Git::Commit / release snapshot]
@@ -658,7 +666,8 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     run = cpanm http://URMOM:mysekritpassword@pause.perl.org/pub/PAUSE/authors/id/U/UR/URMOM/%a
 
     [Run::AfterRelease / release complete]
-    :version = 0.024
+    :version = 0.038
+    quiet = 1
     eval = print "release complete!\\xa"
 
     ; listed late, to allow all other plugins which do BeforeRelease checks to run first.
@@ -713,10 +722,11 @@ to L<C<ModuleBuildTiny>|Dist::Zilla::Plugin::ModuleBuildTiny::Fallback>
 and L<C<MakeMaker::Fallback>|Dist::Zilla::Plugin::MakeMaker::Fallback>
 (which generates a F<Build.PL> for normal use with no-configure-requires
 protection, and F<Makefile.PL> as a fallback, containing an upgrade warning).
+For toolchain-grade modules, you should only use F<Makefile.PL>-generating installers.
 
 You can select other backends (by plugin name, without the C<[]>), with the
 C<installer> option, or 'none' if you are supplying your own, as a separate
-plugin.
+plugin(s).
 
 Encouraged choices are:
 
